@@ -77,6 +77,8 @@ from .basic_components import (
     TaxAmount,
     TaxCurrencyCode,
     TaxExclusiveAmount,
+    TaxExemptionReason,
+    TaxExemptionReasonCode,
     TaxInclusiveAmount,
     Telephone,
     UBLVersionID,
@@ -130,6 +132,8 @@ __all__ = [
     "TaxableAmount",
     "TaxAmount",
     "TaxExclusiveAmount",
+    "TaxExemptionReason",
+    "TaxExemptionReasonCode",
     "TaxInclusiveAmount",
     # Basic components (Quantity subclasses)
     "CreditedQuantity",
