@@ -766,6 +766,16 @@ class Note(StrElement):
     """UBL cbc:Note - Line-level note or document note."""
 
 
+@dataclass
+class TaxExemptionReason(StrElement):
+    """UBL cbc:TaxExemptionReason - Textual reason for tax exemption (BT-120)."""
+
+
+@dataclass
+class TaxExemptionReasonCode(StrElement):
+    """UBL cbc:TaxExemptionReasonCode - Coded reason for tax exemption (BT-121)."""
+
+
 @dataclass
 class RegistrationName(StrElement):
     """UBL cbc:RegistrationName - Legal registration name of a party."""
