@@ -81,7 +81,7 @@ class SimpleTypeCastMixin:
             return expected_type(value)
         except Exception as e:
             raise TypeError(
-                f'Cannot cast field "{field_name}" from {type(value).get("__name__", "None")} to {expected_type.__name__}: {e}'
+                f'Cannot cast field "{field_name}" from {getattr(type(value), "__name__", "None")} to {expected_type.__name__}: {e}'
             )
 
 
@@ -511,6 +511,38 @@ class FromXMLMixin:
     class_name_to_attr: ClassVar[dict[str, str]]
     # property_attr_names: computed as @property in BaseElement
 
+    @classmethod
+    def _get_class_name_to_attr_mapping(cls) -> dict[str, str]:
+        """
+        Get the class_name_to_attr mapping safely from a classmethod context.
+
+        This handles both ClassVar and @property versions of class_name_to_attr.
+        When class_name_to_attr is a property, we access _base_class_name_to_attr instead.
+
+        Returns:
+            Dictionary mapping XML element names to attribute names
+        """
+        # Try _base_class_name_to_attr first (used when class_name_to_attr is a property)
+        if hasattr(cls, '_base_class_name_to_attr'):
+            return cls._base_class_name_to_attr
+
+        # Check if class_name_to_attr is a property
+        class_attr = getattr(cls, 'class_name_to_attr', None)
+        if isinstance(class_attr, property):
+            # Property case - search parent classes for base mapping
+            for base in cls.__mro__[1:]:
+                if hasattr(base, '_base_class_name_to_attr'):
+                    return base._base_class_name_to_attr
+                elif hasattr(base, 'class_name_to_attr'):
+                    base_attr = getattr(base, 'class_name_to_attr', None)
+                    if not isinstance(base_attr, property):
+                        return base_attr
+            # If we can't find a base mapping, return empty dict
+            return {}
+        else:
+            # ClassVar case - return directly
+            return class_attr if class_attr is not None else {}
+
     @classmethod
     def from_xml(cls, element: etree.Element) -> 'FromXMLMixin':
         """
@@ -549,7 +581,8 @@ class FromXMLMixin:
                 tag = etree.QName(child).localname
 
                 # Look up corresponding attribute name
-                attr_name = cls.class_name_to_attr.get(tag)
+                mapping = cls._get_class_name_to_attr_mapping()
+                attr_name = mapping.get(tag)
                 if attr_name is None:
                     # Unknown child element - skip
                     continue
